==> xlniuxdata-vipgame-1.0.65-20160714.070612-14-sources.jar: com/xunlei/niux/data/vipgame/bo/vic/VicGroupsBoImpl.java <==
package com.xunlei.niux.data.vipgame.bo.vic;

import com.ferret.common.dao.BaseDao;
import com.xunlei.niux.data.vipgame.vo.vicclub.VicGroupsOperators;
import com.xunlei.niux.data.vipgame.vo.vicclub.VicOperators;

import java.util.ArrayList;
import java.util.List;

/**
 * Created by zy on 2016/7/13.
 */
public class VicGroupsBoImpl implements VicGroupsBo{

    private BaseDao baseDao;

    public BaseDao getBaseDao() {
        return baseDao;
    }

    public void setBaseDao(BaseDao baseDao) {
        this.baseDao = baseDao;
    }

    @Override
    public List<VicGroupsOperators> getInGroup(Long groupId) {
        String sql = "select * from vic_groups_operators where groupId = ? order by orderNo ";
        List<Object> list = new ArrayList<Object>();
        list.add(groupId);
        return baseDao.findBySql(VicGroupsOperators.class,sql,list);
    }

    @Override
    public List<VicOperators> getOutGroup() {
        String sql = "select vo.* from vic_operators vo \n" +
                " left join vic_groups_operators vgo on vo.seqId = vgo.operatorId \n" +
                " where vgo.groupId is null ";
        return baseDao.findBySql(VicOperators.class,sql,new ArrayList<Object>());
    }

    @Override
    public void out2in(Long groupId, String[] operators,String user ,String time) {
        for(String operator : operators){
            VicGroupsOperators vgp = new VicGroupsOperators();
            vgp.setGroupId(groupId);
            vgp.setOperatorId(Long.valueOf(operator));
            vgp.setEditBy(user);
            vgp.setEditTime(time);
            baseDao.insert(vgp);
        }
    }

    @Override
    public void in2out(Long groupId, String[] operators) {
        if(operators==null||operators.length==0)
            return;
        List<Object> param = new ArrayList<Object>();
        param.add(groupId);
        String sql = " delete from vic_groups_operators where groupId = ? and operatorId in (";
        for(String operator : operators ){
            sql += " ?,";
            param.add(operator);
        }
        sql = sql.substring(0,sql.length()-1)+" )";
        baseDao.execute(sql,param);
    }
}

==> xlniuxdata-vipgame-1.0.65-20160714.072336-15-sources.jar: com/xunlei/niux/data/vipgame/bo/vic/VicGroupsBoImpl.java <==
package com.xunlei.niux.data.vipgame.bo.vic;

import com.ferret.common.dao.BaseDao;
import com.xunlei.niux.data.vipgame.vo.vicclub.VicGroupsOperators;
import com.xunlei.niux.data.vipgame.vo.vicclub.VicOperators;

import java.util.ArrayList;
import java.util.List;

/**
 * Created by zy on 2016/7/13.
 */
public class VicGroupsBoImpl implements VicGroupsBo{

    private BaseDao baseDao;

    public BaseDao getBaseDao() {
        return baseDao;
    }

    public void setBaseDao(BaseDao baseDao) {
        this.baseDao = baseDao;
    }

    @Override
    public List<VicGroupsOperators> getInGroup(Long groupId) {
        String sql = "select * from vic_groups_operators where groupId = ? order by orderNo ";
        List<Object> list = new ArrayList<Object>();
        list.add(groupId);
        return baseDao.findBySql(VicGroupsOperators.class,sql,list);
    }

    @Override
    public List<VicOperators> getOutGroup() {
        String sql = "select vo.* from vic_operators vo \n" +
                " left join vic_groups_operators vgo on vo.seqId = vgo.operatorId \n" +
                " where vgo.groupId is null ";
        return baseDao.findBySql(VicOperators.class,sql,new ArrayList<Object>());
    }

    @Override
    public void out2in(Long groupId, String[] operators,String user ,String time) {
        for(String operator : operators){
            VicGroupsOperators vgp = new VicGroupsOperators();
            vgp.setGroupId(groupId);
            vgp.setOperatorId(Long.valueOf(operator));
            vgp.setEditBy(user);
            vgp.setEditTime(time);
            baseDao.insert(vgp);
        }
    }

    @Override
    public void in2out(Long groupId, String[] operators) {
        if(operators==null||operators.length==0)
            return;
        List<Object> param = new ArrayList<Object>();
        param.add(groupId);
        String sql = " delete from vic_groups_operators where seqId in (";
        for(String operator : operators ){
            sql += " ?,";
            param.add(operator);
        }
        sql = sql.substring(0,sql.length()-1)+" )";
        baseDao.execute(sql,param);
    }
}
